Contributing
============

Fork, then clone the repo:

```
git@github.com:YOUR-USERNAME/hier_config.git
```

Set up your environment:

```
cd hier_config
python3 -m venv env
source venv/bin/activate
./setup.py install
```

Create a branch

```
git checkout -b YOUR-BRANCH
```

Make sure tests pass:

```
./tests/tests.py
```

Make your change. Add tests for your change. Make the tests pass:

```
./tests/tests.py
```

Push to your fork and submit a pull request.

At this point, you're waiting on us. We'll at least comment. We may suggest changes, improvements, or alternatives.

Some things that will increase the chance that your pull request is accepted:

* Write to the python style-guide (https://www.python.org/dev/peps/pep-0008/).
* Write tests.
* Write docstrings (https://www.python.org/dev/peps/pep-0257/).
* Write a good commit message.

